==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusBrokeredMessagePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property contentType Gets or sets the content type.
 * @property correlationId Gets or sets the correlation ID.
 * @property forcePersistence Gets or sets the force persistence.
 * @property label Gets or sets the label.
 * @property messageId Gets or sets the message ID.
 * @property partitionKey Gets or sets the partition key.
 * @property replyTo Gets or sets the reply to.
 * @property replyToSessionId Gets or sets the reply to session ID.
 * @property scheduledEnqueueTimeUtc Gets or sets the scheduled enqueue time UTC.
 * @property sessionId Gets or sets the session ID.
 * @property timeToLive Gets or sets the time to live.
 * @property to Gets or sets the to.
 * @property viaPartitionKey Gets or sets the via partition key.
 */
public data class ServiceBusBrokeredMessagePropertiesArgs(
    public val contentType: Output<String>? = null,
    public val correlationId: Output<String>? = null,
    public val forcePersistence: Output<Boolean>? = null,
    public val label: Output<String>? = null,
    public val messageId: Output<String>? = null,
    public val partitionKey: Output<String>? = null,
    public val replyTo: Output<String>? = null,
    public val replyToSessionId: Output<String>? = null,
    public val scheduledEnqueueTimeUtc: Output<String>? = null,
    public val sessionId: Output<String>? = null,
    public val timeToLive: Output<String>? = null,
    public val to: Output<String>? = null,
    public val viaPartitionKey: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs.builder()
            .contentType(contentType?.applyValue({ args0 -> args0 }))
            .correlationId(correlationId?.applyValue({ args0 -> args0 }))
            .forcePersistence(forcePersistence?.applyValue({ args0 -> args0 }))
            .label(label?.applyValue({ args0 -> args0 }))
            .messageId(messageId?.applyValue({ args0 -> args0 }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0 }))
            .replyTo(replyTo?.applyValue({ args0 -> args0 }))
            .replyToSessionId(replyToSessionId?.applyValue({ args0 -> args0 }))
            .scheduledEnqueueTimeUtc(scheduledEnqueueTimeUtc?.applyValue({ args0 -> args0 }))
            .sessionId(sessionId?.applyValue({ args0 -> args0 }))
            .timeToLive(timeToLive?.applyValue({ args0 -> args0 }))
            .to(to?.applyValue({ args0 -> args0 }))
            .viaPartitionKey(viaPartitionKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceBusBrokeredMessagePropertiesArgs].
 */
@PulumiTagMarker
public class ServiceBusBrokeredMessagePropertiesArgsBuilder internal constructor() {
    private var contentType: Output<String>? = null

    private var correlationId: Output<String>? = null

    private var forcePersistence: Output<Boolean>? = null

    private var label: Output<String>? = null

    private var messageId: Output<String>? = null

    private var partitionKey: Output<String>? = null

    private var replyTo: Output<String>? = null

    private var replyToSessionId: Output<String>? = null

    private var scheduledEnqueueTimeUtc: Output<String>? = null

    private var sessionId: Output<String>? = null

    private var timeToLive: Output<String>? = null

    private var to: Output<String>? = null

    private var viaPartitionKey: Output<String>? = null

    /**
     * @param value Gets or sets the content type.
     */
    @JvmName("bxxfospihrvibfem")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Gets or sets the correlation ID.
     */
    @JvmName("xvsfktwnallkbeov")
    public suspend fun correlationId(`value`: Output<String>) {
        this.correlationId = value
    }

    /**
     * @param value Gets or sets the force persistence.
     */
    @JvmName("wofanatjdywochbs")
    public suspend fun forcePersistence(`value`: Output<Boolean>) {
        this.forcePersistence = value
    }

    /**
     * @param value Gets or sets the label.
     */
    @JvmName("aphlxdrekbadsxqe")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Gets or sets the message ID.
     */
    @JvmName("fjtwkfolwciqnuno")
    public suspend fun messageId(`value`: Output<String>) {
        this.messageId = value
    }

    /**
     * @param value Gets or sets the partition key.
     */
    @JvmName("pqylxaijdcrkafwo")
    public suspend fun partitionKey(`value`: Output<String>) {
        this.partitionKey = value
    }

    /**
     * @param value Gets or sets the reply to.
     */
    @JvmName("cnogspiivalffiio")
    public suspend fun replyTo(`value`: Output<String>) {
        this.replyTo = value
    }

    /**
     * @param value Gets or sets the reply to session ID.
     */
    @JvmName("uswikbrekqbslcgg")
    public suspend fun replyToSessionId(`value`: Output<String>) {
        this.replyToSessionId = value
    }

    /**
     * @param value Gets or sets the scheduled enqueue time UTC.
     */
    @JvmName("udtiddvfwmiqpikk")
    public suspend fun scheduledEnqueueTimeUtc(`value`: Output<String>) {
        this.scheduledEnqueueTimeUtc = value
    }

    /**
     * @param value Gets or sets the session ID.
     */
    @JvmName("wiftmejpbubylgos")
    public suspend fun sessionId(`value`: Output<String>) {
        this.sessionId = value
    }

    /**
     * @param value Gets or sets the time to live.
     */
    @JvmName("bphdaxpehrpsffus")
    public suspend fun timeToLive(`value`: Output<String>) {
        this.timeToLive = value
    }

    /**
     * @param value Gets or sets the to.
     */
    @JvmName("vboqfebwlencsbyh")
    public suspend fun to(`value`: Output<String>) {
        this.to = value
    }

    /**
     * @param value Gets or sets the via partition key.
     */
    @JvmName("xsxpmujmlsiokbii")
    public suspend fun viaPartitionKey(`value`: Output<String>) {
        this.viaPartitionKey = value
    }

    /**
     * @param value Gets or sets the content type.
     */
    @JvmName("ienyjiaemiqiritf")
    public suspend fun contentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Gets or sets the correlation ID.
     */
    @JvmName("hjhcpdotrprkxpri")
    public suspend fun correlationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.correlationId = mapped
    }

    /**
     * @param value Gets or sets the force persistence.
     */
    @JvmName("oteqgbvspwdllqvm")
    public suspend fun forcePersistence(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forcePersistence = mapped
    }

    /**
     * @param value Gets or sets the label.
     */
    @JvmName("fekkiyxocrdqcfgu")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Gets or sets the message ID.
     */
    @JvmName("jjendadrucprbvth")
    public suspend fun messageId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageId = mapped
    }

    /**
     * @param value Gets or sets the partition key.
     */
    @JvmName("wkeymtcchivaysvq")
    public suspend fun partitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param value Gets or sets the reply to.
     */
    @JvmName("rgphpoqhhimexjdy")
    public suspend fun replyTo(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replyTo = mapped
    }

    /**
     * @param value Gets or sets the reply to session ID.
     */
    @JvmName("tfpnvqeeyrfreqry")
    public suspend fun replyToSessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replyToSessionId = mapped
    }

    /**
     * @param value Gets or sets the scheduled enqueue time UTC.
     */
    @JvmName("uyebrhtonneeqqhb")
    public suspend fun scheduledEnqueueTimeUtc(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduledEnqueueTimeUtc = mapped
    }

    /**
     * @param value Gets or sets the session ID.
     */
    @JvmName("gyjbrmaikgkjxtfv")
    public suspend fun sessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionId = mapped
    }

    /**
     * @param value Gets or sets the time to live.
     */
    @JvmName("pgbmvtarxtgibyaj")
    public suspend fun timeToLive(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeToLive = mapped
    }

    /**
     * @param value Gets or sets the to.
     */
    @JvmName("daujfmrttudrsdlv")
    public suspend fun to(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.to = mapped
    }

    /**
     * @param value Gets or sets the via partition key.
     */
    @JvmName("ddxdgfigrcxppaec")
    public suspend fun viaPartitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.viaPartitionKey = mapped
    }

    internal fun build(): ServiceBusBrokeredMessagePropertiesArgs =
        ServiceBusBrokeredMessagePropertiesArgs(
            contentType = contentType,
            correlationId = correlationId,
            forcePersistence = forcePersistence,
            label = label,
            messageId = messageId,
            partitionKey = partitionKey,
            replyTo = replyTo,
            replyToSessionId = replyToSessionId,
            scheduledEnqueueTimeUtc = scheduledEnqueueTimeUtc,
            sessionId = sessionId,
            timeToLive = timeToLive,
            to = to,
            viaPartitionKey = viaPartitionKey,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusBrokeredMessagePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property contentType Gets or sets the content type.
 * @property correlationId Gets or sets the correlation ID.
 * @property forcePersistence Gets or sets the force persistence.
 * @property label Gets or sets the label.
 * @property messageId Gets or sets the message ID.
 * @property partitionKey Gets or sets the partition key.
 * @property replyTo Gets or sets the reply to.
 * @property replyToSessionId Gets or sets the reply to session ID.
 * @property scheduledEnqueueTimeUtc Gets or sets the scheduled enqueue time UTC.
 * @property sessionId Gets or sets the session ID.
 * @property timeToLive Gets or sets the time to live.
 * @property to Gets or sets the to.
 * @property viaPartitionKey Gets or sets the via partition key.
 */
public data class ServiceBusBrokeredMessagePropertiesArgs(
    public val contentType: Output<String>? = null,
    public val correlationId: Output<String>? = null,
    public val forcePersistence: Output<Boolean>? = null,
    public val label: Output<String>? = null,
    public val messageId: Output<String>? = null,
    public val partitionKey: Output<String>? = null,
    public val replyTo: Output<String>? = null,
    public val replyToSessionId: Output<String>? = null,
    public val scheduledEnqueueTimeUtc: Output<String>? = null,
    public val sessionId: Output<String>? = null,
    public val timeToLive: Output<String>? = null,
    public val to: Output<String>? = null,
    public val viaPartitionKey: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusBrokeredMessagePropertiesArgs.builder()
            .contentType(contentType?.applyValue({ args0 -> args0 }))
            .correlationId(correlationId?.applyValue({ args0 -> args0 }))
            .forcePersistence(forcePersistence?.applyValue({ args0 -> args0 }))
            .label(label?.applyValue({ args0 -> args0 }))
            .messageId(messageId?.applyValue({ args0 -> args0 }))
            .partitionKey(partitionKey?.applyValue({ args0 -> args0 }))
            .replyTo(replyTo?.applyValue({ args0 -> args0 }))
            .replyToSessionId(replyToSessionId?.applyValue({ args0 -> args0 }))
            .scheduledEnqueueTimeUtc(scheduledEnqueueTimeUtc?.applyValue({ args0 -> args0 }))
            .sessionId(sessionId?.applyValue({ args0 -> args0 }))
            .timeToLive(timeToLive?.applyValue({ args0 -> args0 }))
            .to(to?.applyValue({ args0 -> args0 }))
            .viaPartitionKey(viaPartitionKey?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ServiceBusBrokeredMessagePropertiesArgs].
 */
@PulumiTagMarker
public class ServiceBusBrokeredMessagePropertiesArgsBuilder internal constructor() {
    private var contentType: Output<String>? = null

    private var correlationId: Output<String>? = null

    private var forcePersistence: Output<Boolean>? = null

    private var label: Output<String>? = null

    private var messageId: Output<String>? = null

    private var partitionKey: Output<String>? = null

    private var replyTo: Output<String>? = null

    private var replyToSessionId: Output<String>? = null

    private var scheduledEnqueueTimeUtc: Output<String>? = null

    private var sessionId: Output<String>? = null

    private var timeToLive: Output<String>? = null

    private var to: Output<String>? = null

    private var viaPartitionKey: Output<String>? = null

    /**
     * @param value Gets or sets the content type.
     */
    @JvmName("nfqppexgupnojmap")
    public suspend fun contentType(`value`: Output<String>) {
        this.contentType = value
    }

    /**
     * @param value Gets or sets the correlation ID.
     */
    @JvmName("ppuinogiajwrsepa")
    public suspend fun correlationId(`value`: Output<String>) {
        this.correlationId = value
    }

    /**
     * @param value Gets or sets the force persistence.
     */
    @JvmName("tluopgnjbbqkvsgl")
    public suspend fun forcePersistence(`value`: Output<Boolean>) {
        this.forcePersistence = value
    }

    /**
     * @param value Gets or sets the label.
     */
    @JvmName("aphsvgdoefikfqgv")
    public suspend fun label(`value`: Output<String>) {
        this.label = value
    }

    /**
     * @param value Gets or sets the message ID.
     */
    @JvmName("abpbtpluqjlxkvqq")
    public suspend fun messageId(`value`: Output<String>) {
        this.messageId = value
    }

    /**
     * @param value Gets or sets the partition key.
     */
    @JvmName("ukuyyvnswjsoawql")
    public suspend fun partitionKey(`value`: Output<String>) {
        this.partitionKey = value
    }

    /**
     * @param value Gets or sets the reply to.
     */
    @JvmName("afgmcarjpkrskvvu")
    public suspend fun replyTo(`value`: Output<String>) {
        this.replyTo = value
    }

    /**
     * @param value Gets or sets the reply to session ID.
     */
    @JvmName("pcermbnqbdsunyck")
    public suspend fun replyToSessionId(`value`: Output<String>) {
        this.replyToSessionId = value
    }

    /**
     * @param value Gets or sets the scheduled enqueue time UTC.
     */
    @JvmName("ojlflwgfxfbkrglh")
    public suspend fun scheduledEnqueueTimeUtc(`value`: Output<String>) {
        this.scheduledEnqueueTimeUtc = value
    }

    /**
     * @param value Gets or sets the session ID.
     */
    @JvmName("tvsiwiwwkljtahgn")
    public suspend fun sessionId(`value`: Output<String>) {
        this.sessionId = value
    }

    /**
     * @param value Gets or sets the time to live.
     */
    @JvmName("omjpkaicecowvblu")
    public suspend fun timeToLive(`value`: Output<String>) {
        this.timeToLive = value
    }

    /**
     * @param value Gets or sets the to.
     */
    @JvmName("txmhnjblgxronydt")
    public suspend fun to(`value`: Output<String>) {
        this.to = value
    }

    /**
     * @param value Gets or sets the via partition key.
     */
    @JvmName("jlwshvoqwebhwpfk")
    public suspend fun viaPartitionKey(`value`: Output<String>) {
        this.viaPartitionKey = value
    }

    /**
     * @param value Gets or sets the content type.
     */
    @JvmName("rtkjmfiqqfwsmdew")
    public suspend fun contentType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.contentType = mapped
    }

    /**
     * @param value Gets or sets the correlation ID.
     */
    @JvmName("tttiowgtjllxctgo")
    public suspend fun correlationId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.correlationId = mapped
    }

    /**
     * @param value Gets or sets the force persistence.
     */
    @JvmName("lweodyaglwhnmrso")
    public suspend fun forcePersistence(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.forcePersistence = mapped
    }

    /**
     * @param value Gets or sets the label.
     */
    @JvmName("mgrdojtlxyxtifrc")
    public suspend fun label(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.label = mapped
    }

    /**
     * @param value Gets or sets the message ID.
     */
    @JvmName("rbnvgpwvywqhjlhy")
    public suspend fun messageId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.messageId = mapped
    }

    /**
     * @param value Gets or sets the partition key.
     */
    @JvmName("bhdqmdbvoaflriqc")
    public suspend fun partitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.partitionKey = mapped
    }

    /**
     * @param value Gets or sets the reply to.
     */
    @JvmName("orcvjrgtleayqfdd")
    public suspend fun replyTo(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replyTo = mapped
    }

    /**
     * @param value Gets or sets the reply to session ID.
     */
    @JvmName("lnnvkkewlehdtprw")
    public suspend fun replyToSessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replyToSessionId = mapped
    }

    /**
     * @param value Gets or sets the scheduled enqueue time UTC.
     */
    @JvmName("yukyldeaeykrtemc")
    public suspend fun scheduledEnqueueTimeUtc(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduledEnqueueTimeUtc = mapped
    }

    /**
     * @param value Gets or sets the session ID.
     */
    @JvmName("lrplcxkkujhpnhnv")
    public suspend fun sessionId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sessionId = mapped
    }

    /**
     * @param value Gets or sets the time to live.
     */
    @JvmName("pliwskjgrtywipon")
    public suspend fun timeToLive(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.timeToLive = mapped
    }

    /**
     * @param value Gets or sets the to.
     */
    @JvmName("bybdvqjwasnmlikh")
    public suspend fun to(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.to = mapped
    }

    /**
     * @param value Gets or sets the via partition key.
     */
    @JvmName("njyrnadxvbcaggho")
    public suspend fun viaPartitionKey(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.viaPartitionKey = mapped
    }

    internal fun build(): ServiceBusBrokeredMessagePropertiesArgs =
        ServiceBusBrokeredMessagePropertiesArgs(
            contentType = contentType,
            correlationId = correlationId,
            forcePersistence = forcePersistence,
            label = label,
            messageId = messageId,
            partitionKey = partitionKey,
            replyTo = replyTo,
            replyToSessionId = replyToSessionId,
            scheduledEnqueueTimeUtc = scheduledEnqueueTimeUtc,
            sessionId = sessionId,
            timeToLive = timeToLive,
            to = to,
            viaPartitionKey = viaPartitionKey,
        )
}
